@@ -1,5 +1,8 @@
 use super::{bool_t, uint_t, ATR, ER, ER_ID, ER_UINT, EXINF, ID, PRI, RELTIM, STAT, TMO};
 
+/*
+ *  処理単位の型定義
+ */
 pub type TASK = Option<unsafe extern "C" fn(EXINF)>;
 
 /*
@@ -254,3 +257,9 @@ extern "C" {
     pub fn sns_ter() -> bool_t;
     pub fn ter_tsk(tskid: ID) -> ER;
 }
+
+/// 自タスクの終了＆削除
+#[cfg(any(feature = "solid_asp3", feature = "solid_fmp3"))]
+extern "C" {
+    pub fn exd_tsk() -> ER;
+}
